@@ -23,7 +23,6 @@
 
 #include <QLineEdit>
 #include <KLocalizedString>
-#include <QDialog>
 #include <QSpinBox>
 
 #include <QLabel>
@@ -37,15 +36,12 @@ class NoteShared::NoteNetworkConfigWidgetPrivate
 {
 public:
     NoteNetworkConfigWidgetPrivate()
-        : mTmpChkB(nullptr)
-        , kcfg_SenderID(nullptr)
-        , kcfg_Port(nullptr)
     {
     }
 
-    QCheckBox *mTmpChkB;
-    QLineEdit *kcfg_SenderID;
-    QSpinBox *kcfg_Port;
+    QCheckBox *mTmpChkB = nullptr;
+    QLineEdit *kcfg_SenderID = nullptr;
+    QSpinBox *kcfg_Port = nullptr;
 };
 
 NoteNetworkConfigWidget::NoteNetworkConfigWidget(QWidget *parent)
