@@ -23,73 +23,56 @@
 
 #include "knotes_part.h"
 #include "knotes_kontact_plugin_debug.h"
+#include "knoteedit.h"
+#include "knotesadaptor.h"
+#include "knoteseditdialog.h"
+#include "knotesglobalconfig.h"
+#include "knotesiconview.h"
+#include "knotesselectdeletenotesdialog.h"
+#include "knoteswidget.h"
 #include "notesharedglobalconfig.h"
 #include "noteutils.h"
-#include "knoteseditdialog.h"
-#include "knotesadaptor.h"
-#include "knotesiconview.h"
-#include "knoteswidget.h"
-#include "knotesselectdeletenotesdialog.h"
+#include "alarms/notealarmdialog.h"
+#include "akonadi/notesakonaditreemodel.h"
+#include "akonadi/noteschangerecorder.h"
+#include "attributes/notealarmattribute.h"
+#include "attributes/notedisplayattribute.h"
+#include "attributes/notelockattribute.h"
+#include "attributes/showfoldernotesattribute.h"
 #include "configdialog/knoteconfigdialog.h"
+#include "configdialog/knotesimpleconfigdialog.h"
+#include "finddialog/knotefinddialog.h"
+#include "job/createnewnotejob.h"
 #include "print/knoteprinter.h"
 #include "print/knoteprintobject.h"
 #include "print/knoteprintselectthemedialog.h"
-#include "knoteedit.h"
-#include "knotesglobalconfig.h"
-#include "configdialog/knotesimpleconfigdialog.h"
-#include "finddialog/knotefinddialog.h"
+#include "resources/localresourcecreator.h"
 #include "utils/knoteutils.h"
-#include "alarms/notealarmdialog.h"
-#include "job/createnewnotejob.h"
 
-#include "akonadi/notesakonaditreemodel.h"
-#include "job/createnewnotejob.h"
-#include "attributes/notealarmattribute.h"
-#include "attributes/showfoldernotesattribute.h"
-#include "attributes/notealarmattribute.h"
-#include "attributes/notelockattribute.h"
-#include "attributes/notelockattribute.h"
-
-#include <Akonadi/Notes/NoteUtils>
-
-#include <KDateTime>
-#include <AkonadiCore/Session>
 #include <AkonadiCore/ChangeRecorder>
-#include <AkonadiWidgets/ETMViewStateSaver>
-#include <AkonadiCore/EntityDisplayAttribute>
-#include <AkonadiCore/ItemCreateJob>
+#include <AkonadiCore/ItemDeleteJob>
 #include <AkonadiCore/ItemFetchJob>
-#include <KCheckableProxyModel>
-#include <AkonadiCore/itemdeletejob.h>
 #include <AkonadiCore/ItemFetchScope>
+#include <AkonadiCore/ItemModifyJob>
+#include <AkonadiCore/Session>
+#include <AkonadiWidgets/ControlGui>
+#include <AkonadiWidgets/ETMViewStateSaver>
 
-#include <QUrl>
-#include <QFileDialog>
 #include <KMime/KMimeMessage>
 
-#include <AkonadiCore/ItemModifyJob>
-#include <AkonadiWidgets/ControlGui>
-#include <akonadi/noteschangerecorder.h>
-#include <attributes/notedisplayattribute.h>
-#include <resources/localresourcecreator.h>
-
 #include <KActionCollection>
-#include <QAction>
-#include <QInputDialog>
-#include <KMessageBox>
-#include <KXMLGUIFactory>
-#include <KFileDialog>
-#include <KToggleAction>
+#include <KCheckableProxyModel>
 #include <KLocalizedString>
-#include <QIcon>
+#include <KMessageBox>
+#include <KDNSSD/DNSSD/PublicService>
 
 #include <QApplication>
-#include <QClipboard>
-#include <QMenu>
-#include <QPointer>
 #include <QCheckBox>
-
-#include <dnssd/publicservice.h>
+#include <QClipboard>
+#include <QFileDialog>
+#include <QInputDialog>
+#include <QItemSelectionModel>
+#include <QMenu>
 
 KNotesPart::KNotesPart(QObject *parent)
     : KParts::ReadOnlyPart(parent)
@@ -114,7 +97,9 @@ KNotesPart::KNotesPart(QObject *parent)
     mNewNote = new QAction(QIcon::fromTheme(QStringLiteral("knotes")),
                            i18nc("@action:inmenu create new popup note", "&New"), this);
     actionCollection()->addAction(QStringLiteral("file_new"), mNewNote);
-    connect(mNewNote, SIGNAL(triggered(bool)), SLOT(newNote()));
+    connect(mNewNote, &QAction::triggered, this, [this]() {
+        newNote();
+    });
     actionCollection()->setDefaultShortcut(mNewNote, QKeySequence(Qt::CTRL + Qt::Key_N));
     //mNewNote->setHelpText(
     //            i18nc( "@info:status", "Create a new popup note" ) );
@@ -125,7 +110,9 @@ KNotesPart::KNotesPart(QObject *parent)
     mNoteEdit = new QAction(QIcon::fromTheme(QStringLiteral("document-edit")),
                             i18nc("@action:inmenu", "Edit..."), this);
     actionCollection()->addAction(QStringLiteral("edit_note"), mNoteEdit);
-    connect(mNoteEdit, SIGNAL(triggered(bool)), SLOT(editNote()));
+    connect(mNoteEdit, &QAction::triggered, this, [this]() {
+        editNote();
+    });
     //mNoteEdit->setHelpText(
     //            i18nc( "@info:status", "Edit popup note" ) );
     mNoteEdit->setWhatsThis(
@@ -165,28 +152,34 @@ KNotesPart::KNotesPart(QObject *parent)
         i18nc("@info:whatsthis",
               "You will be prompted to print the selected popup note."));
 
-    mNotePrintPreview = new QAction(QIcon::fromTheme(QStringLiteral("document-print-preview")), i18nc("@action:inmenu", "Print Preview Selected Notes..."), this);
+    mNotePrintPreview = new QAction(QIcon::fromTheme(QStringLiteral("document-print-preview")),
+                                    i18nc("@action:inmenu", "Print Preview Selected Notes..."), this);
     actionCollection()->addAction(QStringLiteral("print_preview_note"), mNotePrintPreview);
 
     connect(mNotePrintPreview, &QAction::triggered, this, &KNotesPart::slotPrintPreviewSelectedNotes);
 
-    mNoteConfigure = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Note settings..."), this);
+    mNoteConfigure = new QAction(QIcon::fromTheme(QStringLiteral("configure")),
+                                 i18n("Note settings..."), this);
     actionCollection()->addAction(QStringLiteral("configure_note"), mNoteConfigure);
     connect(mNoteConfigure, &QAction::triggered, this, &KNotesPart::slotNotePreferences);
 
-    QAction *act = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Preferences KNotes..."), this);
+    QAction *act = new QAction(QIcon::fromTheme(QStringLiteral("configure")),
+                               i18n("Preferences KNotes..."), this);
     actionCollection()->addAction(QStringLiteral("knotes_configure"), act);
     connect(act, &QAction::triggered, this, &KNotesPart::slotPreferences);
 
-    mNoteSendMail = new QAction(QIcon::fromTheme(QStringLiteral("mail-send")), i18n("Mail..."), this);
+    mNoteSendMail = new QAction(QIcon::fromTheme(QStringLiteral("mail-send")),
+                                i18n("Mail..."), this);
     actionCollection()->addAction(QStringLiteral("mail_note"), mNoteSendMail);
     connect(mNoteSendMail, &QAction::triggered, this, &KNotesPart::slotMail);
 
-    mNoteSendNetwork = new QAction(QIcon::fromTheme(QStringLiteral("network-wired")), i18n("Send..."), this);
+    mNoteSendNetwork = new QAction(QIcon::fromTheme(QStringLiteral("network-wired")),
+                                   i18n("Send..."), this);
     actionCollection()->addAction(QStringLiteral("send_note"), mNoteSendNetwork);
     connect(mNoteSendNetwork, &QAction::triggered, this, &KNotesPart::slotSendToNetwork);
 
-    mNoteSetAlarm = new QAction(QIcon::fromTheme(QStringLiteral("knotes_alarm")), i18n("Set Alarm..."), this);
+    mNoteSetAlarm = new QAction(QIcon::fromTheme(QStringLiteral("knotes_alarm")),
+                                i18n("Set Alarm..."), this);
     actionCollection()->addAction(QStringLiteral("set_alarm"), mNoteSetAlarm);
     connect(mNoteSetAlarm, &QAction::triggered, this, &KNotesPart::slotSetAlarm);
 
@@ -200,11 +193,13 @@ KNotesPart::KNotesPart(QObject *parent)
     actionCollection()->addAction(QStringLiteral("new_note_from_text_file"), act);
     connect(act, &QAction::triggered, this, &KNotesPart::slotNewNoteFromTextFile);
 
-    mSaveAs = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")), i18n("Save As..."), this);
+    mSaveAs = new QAction(QIcon::fromTheme(QStringLiteral("document-save-as")),
+                          i18n("Save As..."), this);
     actionCollection()->addAction(QStringLiteral("save_note"), mSaveAs);
     connect(mSaveAs, &QAction::triggered, this, &KNotesPart::slotSaveAs);
 
-    mReadOnly = new KToggleAction(QIcon::fromTheme(QStringLiteral("object-locked")), i18n("Lock"), this);
+    mReadOnly = new KToggleAction(QIcon::fromTheme(QStringLiteral("object-locked")),
+                                  i18n("Lock"), this);
     actionCollection()->addAction(QStringLiteral("lock_note"), mReadOnly);
     connect(mReadOnly, &KToggleAction::triggered, this, &KNotesPart::slotUpdateReadOnly);
     mReadOnly->setCheckedState(KGuiItem(i18n("Unlock"), QStringLiteral("object-unlocked")));
@@ -216,11 +211,17 @@ KNotesPart::KNotesPart(QObject *parent)
     mNoteRecorder->changeRecorder()->setSession(session);
     mNoteTreeModel = new NoteShared::NotesAkonadiTreeModel(mNoteRecorder->changeRecorder(), this);
 
-    connect(mNoteTreeModel, &NoteShared::NotesAkonadiTreeModel::rowsInserted, this, &KNotesPart::slotRowInserted);
+    connect(mNoteTreeModel, &NoteShared::NotesAkonadiTreeModel::rowsInserted,
+            this, &KNotesPart::slotRowInserted);
 
-    connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemChanged, this, &KNotesPart::slotItemChanged);
-    connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemRemoved, this, &KNotesPart::slotItemRemoved);
-    connect(mNoteRecorder->changeRecorder(), SIGNAL(collectionChanged(Akonadi::Collection,QSet<QByteArray>)), SLOT(slotCollectionChanged(Akonadi::Collection,QSet<QByteArray>)));
+    connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemChanged,
+            this, &KNotesPart::slotItemChanged);
+
+    connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemRemoved,
+            this, &KNotesPart::slotItemRemoved);
+
+    connect(mNoteRecorder->changeRecorder(), SIGNAL(collectionChanged(Akonadi::Collection,QSet<QByteArray>)),
+            SLOT(slotCollectionChanged(Akonadi::Collection,QSet<QByteArray>)));
 
     mSelectionModel = new QItemSelectionModel(mNoteTreeModel);
     mModelProxy = new KCheckableProxyModel(this);
@@ -229,8 +230,7 @@ KNotesPart::KNotesPart(QObject *parent)
 
     KSharedConfigPtr _config = KSharedConfig::openConfig(QStringLiteral("kcmknotessummaryrc"));
 
-    mModelState
-        = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(_config->group("CheckState"), this);
+    mModelState = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(_config->group("CheckState"), this);
     mModelState->setSelectionModel(mSelectionModel);
 
     mNotesWidget = new KNotesWidget(this, widget());
@@ -241,8 +241,8 @@ KNotesPart::KNotesPart(QObject *parent)
     actionCollection()->addAction(QStringLiteral("focus_to_quickseach"), mQuickSearchAction);
     connect(mQuickSearchAction, &QAction::triggered, mNotesWidget, &KNotesWidget::slotFocusQuickSearch);
 
-    connect(mNotesWidget->notesView(), SIGNAL(itemDoubleClicked(QListWidgetItem *)),
-            this, SLOT(editNote(QListWidgetItem *)));
+    connect(mNotesWidget->notesView(), SIGNAL(itemDoubleClicked(QListWidgetItem*)),
+            this, SLOT(editNote(QListWidgetItem*)));
 
     connect(mNotesWidget->notesView(), &QListWidget::itemSelectionChanged,
             this, &KNotesPart::slotOnCurrentChanged);
@@ -276,7 +276,8 @@ void KNotesPart::slotRowInserted(const QModelIndex &parent, int start, int end)
     for (int i = start; i <= end; ++i) {
         if (mNoteTreeModel->hasIndex(i, 0, parent)) {
             const QModelIndex child = mNoteTreeModel->index(i, 0, parent);
-            Akonadi::Collection parentCollection = mNoteTreeModel->data(child, Akonadi::EntityTreeModel::ParentCollectionRole).value<Akonadi::Collection>();
+            Akonadi::Collection parentCollection
+                = mNoteTreeModel->data(child, Akonadi::EntityTreeModel::ParentCollectionRole).value<Akonadi::Collection>();
             if (parentCollection.hasAttribute<NoteShared::ShowFolderNotesAttribute>()) {
                 Akonadi::Item item
                     = mNoteTreeModel->data(child, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
@@ -387,8 +388,7 @@ void KNotesPart::killNote(Akonadi::Item::Id id, bool force)
                  i18nc("@info", "Do you really want to delete this note?"),
                  QStringList(note->realName()),
                  i18nc("@title:window", "Confirm Delete"),
-                 KStandardGuiItem::del()) == KMessageBox::Continue)
-            || force)) {
+                 KStandardGuiItem::del()) == KMessageBox::Continue) || force)) {
         Akonadi::ItemDeleteJob *job = new Akonadi::ItemDeleteJob(note->item());
         connect(job, &Akonadi::ItemDeleteJob::result, this, &KNotesPart::slotDeleteNotesFinished);
     }
@@ -493,7 +493,10 @@ void KNotesPart::popupRMB(QListWidgetItem *item, const QPoint &pos, const QPoint
     if (mNotesWidget->notesView()->itemAt(pos)) {
         contextMenu->addAction(mNewNote);
         const bool uniqueNoteSelected = (mNotesWidget->notesView()->selectedItems().count() == 1);
-        const bool readOnly = uniqueNoteSelected ? static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->selectedItems().at(0))->readOnly() : false;
+        const bool readOnly = uniqueNoteSelected
+                              ? static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->selectedItems().at(0))->readOnly()
+                              : false;
+
         if (uniqueNoteSelected) {
             if (!readOnly) {
                 contextMenu->addSeparator();
@@ -597,7 +600,8 @@ void KNotesPart::slotOnCurrentChanged()
     mSaveAs->setEnabled(uniqueNoteSelected);
     mReadOnly->setEnabled(uniqueNoteSelected);
     if (uniqueNoteSelected) {
-        const bool readOnly = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->selectedItems().at(0))->readOnly();
+        const bool readOnly
+            = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->selectedItems().at(0))->readOnly();
         mReadOnly->setChecked(readOnly);
         mNoteEdit->setText(readOnly ? i18n("Show Note...") : i18nc("@action:inmenu", "Edit..."));
     } else {
@@ -672,7 +676,9 @@ void KNotesPart::updateNetworkListener()
 
     if (NoteShared::NoteSharedGlobalConfig::receiveNotes()) {
         // create the socket and start listening for connections
-        mPublisher = new KDNSSD::PublicService(NoteShared::NoteSharedGlobalConfig::senderID(), QStringLiteral("_knotes._tcp"), NoteShared::NoteSharedGlobalConfig::port());
+        mPublisher = new KDNSSD::PublicService(NoteShared::NoteSharedGlobalConfig::senderID(),
+                                               QStringLiteral("_knotes._tcp"),
+                                               NoteShared::NoteSharedGlobalConfig::port());
         mPublisher->publishAsync();
     }
 }
@@ -692,7 +698,8 @@ void KNotesPart::slotSetAlarm()
         bool needToModify = true;
         QDateTime dateTime = dlg->alarm();
         if (dateTime.isValid()) {
-            NoteShared::NoteAlarmAttribute *attribute = item.attribute<NoteShared::NoteAlarmAttribute>(Akonadi::Item::AddIfMissing);
+            NoteShared::NoteAlarmAttribute *attribute
+                = item.attribute<NoteShared::NoteAlarmAttribute>(Akonadi::Item::AddIfMissing);
             attribute->setDateTime(dateTime);
         } else {
             if (item.hasAttribute<NoteShared::NoteAlarmAttribute>()) {
@@ -730,34 +737,27 @@ void KNotesPart::slotSaveAs()
     }
     KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
 
-    QUrl url;
-    QCheckBox *convert = nullptr;
-
+    QStringList filters;
     if (knoteItem->isRichText()) {
-        convert = new QCheckBox(nullptr);
-        convert->setText(i18n("Save note as plain text"));
-    }
-    QPointer<KFileDialog> dlg = new KFileDialog(url, QString(), widget(), convert);
-    dlg->setOperationMode(KFileDialog::Saving);
-    dlg->setWindowTitle(i18n("Save As"));
-    if (!dlg->exec()) {
-        delete dlg;
-        return;
+        filters << i18n("Rich text (*.html)");
     }
+    filters << i18n("Plain text (*.txt)");
 
-    const QString fileName = dlg->selectedFile();
-    const bool htmlFormatAndSaveAsHtml = (convert && !convert->isChecked());
-    delete dlg;
+    QString format;
+    const QString fileName = QFileDialog::getSaveFileName(widget(), i18n("Save As"), QString(),
+                                                          filters.join(QStringLiteral(";;")), &format);
     if (fileName.isEmpty()) {
         return;
     }
+    const bool htmlFormatAndSaveAsHtml = (knoteItem->isRichText() && !format.contains(QStringLiteral("(*.txt)")));
 
     QFile file(fileName);
     if (file.exists()
-        && KMessageBox::warningContinueCancel(widget(),
-                                              i18n("<qt>A file named <b>%1</b> already exists.<br />"
-                                                   "Are you sure you want to overwrite it?</qt>",
-                                                   QFileInfo(file).fileName())) != KMessageBox::Continue) {
+        && KMessageBox::warningContinueCancel(
+            widget(),
+            i18n("<qt>A file named <b>%1</b> already exists.<br />"
+                 "Are you sure you want to overwrite it?</qt>",
+                 QFileInfo(file).fileName())) != KMessageBox::Continue) {
         return;
     }
 
@@ -767,7 +767,8 @@ void KNotesPart::slotSaveAs()
         doc.setHtml(knoteItem->description());
         if (htmlFormatAndSaveAsHtml) {
             QString htmlStr = doc.toHtml();
-            htmlStr.replace(QStringLiteral("meta name=\"qrichtext\" content=\"1\""), QStringLiteral("meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\""));
+            htmlStr.replace(QStringLiteral("meta name=\"qrichtext\" content=\"1\""),
+                            QStringLiteral("meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\""));
             stream <<  htmlStr;
         } else {
             stream << knoteItem->realName() + QLatin1Char('\n');
@@ -871,13 +872,15 @@ void KNotesPart::slotNewNoteFromTextFile()
 {
     QString text;
     const QString filename = QFileDialog::getOpenFileName(widget(), i18n("Select Text File"), QString(),
-                                                          i18n("Text File (*.txt)"));
+                                                          QStringLiteral("%1 (*.txt)").arg(i18n("Text File")));
     if (!filename.isEmpty()) {
         QFile f(filename);
         if (f.open(QIODevice::ReadOnly | QIODevice::Text)) {
             text = QString::fromUtf8(f.readAll());
         } else {
-            KMessageBox::error(widget(), i18n("Error during open text file: %1", f.errorString()), i18n("Open Text File"));
+            KMessageBox::error(widget(),
+                               i18n("Error during open text file: %1", f.errorString()),
+                               i18n("Open Text File"));
             return;
         }
         newNote(i18n("Note from file '%1'", filename), text);
