@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -53,7 +53,7 @@ public:
     bool autoIndent() const;
 
 private:
-    NoteShared::NoteDisplayAttribute *mDisplayAttribute;
+    NoteShared::NoteDisplayAttribute *mDisplayAttribute = nullptr;
 };
 
 #endif // KNOTEDISPLAYSETTINGS_H
